package com.bonus.canteen.core.health.mapper;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthPersonBodyRecord;

/**
 * 体征数据记录Mapper接口
 *
 * @author xsheng
 * @date 2025-05-25
 */
public interface HealthPersonBodyRecordMapper {
    /**
     * 查询体征数据记录
     *
     * @param id 体征数据记录主键
     * @return 体征数据记录
     */
    public HealthPersonBodyRecord selectHealthPersonBodyRecordById(Long id);

    /**
     * 查询体征数据记录列表
     *
     * @param healthPersonBodyRecord 体征数据记录
     * @return 体征数据记录集合
     */
    public List<HealthPersonBodyRecord> selectHealthPersonBodyRecordList(HealthPersonBodyRecord healthPersonBodyRecord);

    /**
     * 新增体征数据记录
     *
     * @param healthPersonBodyRecord 体征数据记录
     * @return 结果
     */
    public int insertHealthPersonBodyRecord(HealthPersonBodyRecord healthPersonBodyRecord);

    /**
     * 修改体征数据记录
     *
     * @param healthPersonBodyRecord 体征数据记录
     * @return 结果
     */
    public int updateHealthPersonBodyRecord(HealthPersonBodyRecord healthPersonBodyRecord);

    /**
     * 删除体征数据记录
     *
     * @param id 体征数据记录主键
     * @return 结果
     */
    public int deleteHealthPersonBodyRecordById(Long id);

    /**
     * 批量删除体征数据记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthPersonBodyRecordByIds(Long[] ids);
}
