package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonBodyRecord;
import com.bonus.canteen.core.health.service.IHealthPersonBodyRecordService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 体征数据记录Controller
 *
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "体征数据记录接口")
@RestController
@RequestMapping("/health_person_body_record")
public class HealthPersonBodyRecordController extends BaseController {
    @Autowired
    private IHealthPersonBodyRecordService healthPersonBodyRecordService;

    /**
     * 查询体征数据记录列表
     */
    @ApiOperation(value = "查询体征数据记录列表")
    //@RequiresPermissions("health:record:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonBodyRecord healthPersonBodyRecord) {
        startPage();
        List<HealthPersonBodyRecord> list = healthPersonBodyRecordService.selectHealthPersonBodyRecordList(healthPersonBodyRecord);
        return getDataTable(list);
    }

    /**
     * 导出体征数据记录列表
     */
    @ApiOperation(value = "导出体征数据记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:record:export")
    @SysLog(title = "体征数据记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出体征数据记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonBodyRecord healthPersonBodyRecord) {
        List<HealthPersonBodyRecord> list = healthPersonBodyRecordService.selectHealthPersonBodyRecordList(healthPersonBodyRecord);
        ExcelUtil<HealthPersonBodyRecord> util = new ExcelUtil<HealthPersonBodyRecord>(HealthPersonBodyRecord.class);
        util.exportExcel(response, list, "体征数据记录数据");
    }

    /**
     * 获取体征数据记录详细信息
     */
    @ApiOperation(value = "获取体征数据记录详细信息")
    //@RequiresPermissions("health:record:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthPersonBodyRecordService.selectHealthPersonBodyRecordById(id));
    }

    /**
     * 新增体征数据记录
     */
    @ApiOperation(value = "新增体征数据记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:record:add")
    @SysLog(title = "体征数据记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增体征数据记录")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonBodyRecord healthPersonBodyRecord) {
        try {
            return toAjax(healthPersonBodyRecordService.insertHealthPersonBodyRecord(healthPersonBodyRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改体征数据记录
     */
    @ApiOperation(value = "修改体征数据记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:record:edit")
    @SysLog(title = "体征数据记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改体征数据记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPersonBodyRecord healthPersonBodyRecord) {
        try {
            return toAjax(healthPersonBodyRecordService.updateHealthPersonBodyRecord(healthPersonBodyRecord));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除体征数据记录
     */
    @ApiOperation(value = "删除体征数据记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:record:remove")
    @SysLog(title = "体征数据记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除体征数据记录")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthPersonBodyRecordService.deleteHealthPersonBodyRecordByIds(ids));
    }
}
